@@ -320,7 +320,10 @@ sub _mutation {
 	
 	unless($self->_mutator){
 		my $mutator = q/AI::Genetic::Pro::Mutation::/ . ucfirst(lc($self->type));
-		$mutator->require;
+		unless($mutator->require){
+			$mutator = q/AI::Genetic::Pro::Mutation::Bitvector/;
+			$mutator->require;
+		}
 		$self->_mutator($mutator->new);
 	}
 	
@@ -1018,6 +1021,10 @@ is different.
 
 A small script which yields the problem will probably be of help. 
 
+=head1 THANKS
+
+Thanks to Alec Chen for reporting a bug.
+
 =head1 AUTHOR
 
 Strzelecki Lukasz <strzelec@rswsystems.com>
